@@ -4,12 +4,12 @@
 import argparse #To run the engine in debug mode if the front-end is in debug mode.
 from collections import defaultdict
 import os
-from PyQt5.QtCore import QObject, QTimer, pyqtSlot
+from PyQt5.QtCore import QObject, QTimer, QUrl, pyqtSlot
 import sys
 from time import time
 from typing import Any, cast, Dict, List, Optional, Set, TYPE_CHECKING
 
-from PyQt5.QtGui import QImage
+from PyQt5.QtGui import QDesktopServices, QImage
 
 from UM.Backend.Backend import Backend, BackendState
 from UM.Scene.SceneNode import SceneNode
@@ -157,6 +157,19 @@ class CuraEngineBackend(QObject, Backend):
         self.determineAutoSlicing()
         application.getPreferences().preferenceChanged.connect(self._onPreferencesChanged)
 
+        self._slicing_error_message = Message(
+            text = catalog.i18nc("@message", "Slicing failed with an unexpected error. Please consider reporting a bug on our issue tracker."),
+            title = catalog.i18nc("@message:title", "Slicing failed"),
+            message_type = Message.MessageType.ERROR
+        )
+        self._slicing_error_message.addAction(
+            action_id = "report_bug",
+            name = catalog.i18nc("@message:button", "Report a bug"),
+            description = catalog.i18nc("@message:description", "Report a bug on Ultimaker Cura's issue tracker."),
+            icon = "[no_icon]"
+        )
+        self._slicing_error_message.actionTriggered.connect(self._reportBackendError)
+
         self._snapshot = None #type: Optional[QImage]
 
         application.initializationFinished.connect(self.initialize)
@@ -379,7 +392,9 @@ class CuraEngineBackend(QObject, Backend):
         if job.getResult() == StartJobResult.MaterialIncompatible:
             if application.platformActivity:
                 self._error_message = Message(catalog.i18nc("@info:status",
-                                            "Unable to slice with the current material as it is incompatible with the selected machine or configuration."), title = catalog.i18nc("@info:title", "Unable to slice"))
+                                                            "Unable to slice with the current material as it is incompatible with the selected machine or configuration."),
+                                              title = catalog.i18nc("@info:title", "Unable to slice"),
+                                              message_type = Message.MessageType.WARNING)
                 self._error_message.show()
                 self.setState(BackendState.Error)
                 self.backendError.emit(job)
@@ -409,8 +424,11 @@ class CuraEngineBackend(QObject, Backend):
                         continue
                     error_labels.add(definitions[0].label)
 
-                self._error_message = Message(catalog.i18nc("@info:status", "Unable to slice with the current settings. The following settings have errors: {0}").format(", ".join(error_labels)),
-                                              title = catalog.i18nc("@info:title", "Unable to slice"))
+                self._error_message = Message(catalog.i18nc("@info:status",
+                                                            "Unable to slice with the current settings. The following settings have errors: {0}").format(", ".join(error_labels)),
+                                              title = catalog.i18nc("@info:title", "Unable to slice"),
+                                              message_type = Message.MessageType.WARNING)
+                Logger.warning(f"Unable to slice with the current settings. The following settings have errors: {', '.join(error_labels)}")
                 self._error_message.show()
                 self.setState(BackendState.Error)
                 self.backendError.emit(job)
@@ -433,8 +451,11 @@ class CuraEngineBackend(QObject, Backend):
                         Logger.log("e", "When checking settings for errors, unable to find definition for key {key} in per-object stack.".format(key = key))
                         continue
                     errors[key] = definition[0].label
-            self._error_message = Message(catalog.i18nc("@info:status", "Unable to slice due to some per-model settings. The following settings have errors on one or more models: {error_labels}").format(error_labels = ", ".join(errors.values())),
-                                          title = catalog.i18nc("@info:title", "Unable to slice"))
+            self._error_message = Message(catalog.i18nc("@info:status",
+                                                        "Unable to slice due to some per-model settings. The following settings have errors on one or more models: {error_labels}").format(error_labels = ", ".join(errors.values())),
+                                          title = catalog.i18nc("@info:title", "Unable to slice"),
+                                          message_type = Message.MessageType.WARNING)
+            Logger.warning(f"Unable to slice due to per-object settings. The following settings have errors on one or more models: {', '.join(errors.values())}")
             self._error_message.show()
             self.setState(BackendState.Error)
             self.backendError.emit(job)
@@ -442,17 +463,22 @@ class CuraEngineBackend(QObject, Backend):
 
         if job.getResult() == StartJobResult.BuildPlateError:
             if application.platformActivity:
-                self._error_message = Message(catalog.i18nc("@info:status", "Unable to slice because the prime tower or prime position(s) are invalid."),
-                                              title = catalog.i18nc("@info:title", "Unable to slice"))
+                self._error_message = Message(catalog.i18nc("@info:status",
+                                                            "Unable to slice because the prime tower or prime position(s) are invalid."),
+                                              title = catalog.i18nc("@info:title", "Unable to slice"),
+                                              message_type = Message.MessageType.WARNING)
                 self._error_message.show()
                 self.setState(BackendState.Error)
                 self.backendError.emit(job)
+                return
             else:
                 self.setState(BackendState.NotStarted)
 
         if job.getResult() == StartJobResult.ObjectsWithDisabledExtruder:
-            self._error_message = Message(catalog.i18nc("@info:status", "Unable to slice because there are objects associated with disabled Extruder %s.") % job.getMessage(),
-                                          title = catalog.i18nc("@info:title", "Unable to slice"))
+            self._error_message = Message(catalog.i18nc("@info:status",
+                                                        "Unable to slice because there are objects associated with disabled Extruder %s.") % job.getMessage(),
+                                          title = catalog.i18nc("@info:title", "Unable to slice"),
+                                          message_type = Message.MessageType.WARNING)
             self._error_message.show()
             self.setState(BackendState.Error)
             self.backendError.emit(job)
@@ -464,7 +490,8 @@ class CuraEngineBackend(QObject, Backend):
                                                                             "\n- Fit within the build volume"
                                                                             "\n- Are assigned to an enabled extruder"
                                                                             "\n- Are not all set as modifier meshes"),
-                                              title = catalog.i18nc("@info:title", "Unable to slice"))
+                                              title = catalog.i18nc("@info:title", "Unable to slice"),
+                                              message_type = Message.MessageType.WARNING)
                 self._error_message.show()
                 self.setState(BackendState.Error)
                 self.backendError.emit(job)
@@ -622,7 +649,7 @@ class CuraEngineBackend(QObject, Backend):
         for node in DepthFirstIterator(self._scene.getRoot()):
             if node.callDecoration("getLayerData"):
                 if not build_plate_numbers or node.callDecoration("getBuildPlateNumber") in build_plate_numbers:
-                    # We can asume that all nodes have a parent as we're looping through the scene (and filter out root)
+                    # We can assume that all nodes have a parent as we're looping through the scene (and filter out root)
                     cast(SceneNode, node.getParent()).removeChild(node)
 
     def markSliceAll(self) -> None:
@@ -922,9 +949,22 @@ class CuraEngineBackend(QObject, Backend):
 
         if not self._restart:
             if self._process: # type: ignore
-                Logger.log("d", "Backend quit with return code %s. Resetting process and socket.", self._process.wait()) # type: ignore
+                return_code = self._process.wait()
+                if return_code != 0:
+                    Logger.log("e", f"Backend exited abnormally with return code {return_code}!")
+                    self._slicing_error_message.show()
+                    self.setState(BackendState.Error)
+                    self.stopSlicing()
+                else:
+                    Logger.log("d", "Backend finished slicing. Resetting process and socket.")
                 self._process = None # type: ignore
 
+    def _reportBackendError(self, _message_id: str, _action_id: str) -> None:
+        """
+        Triggered when the user wants to report an error in the back-end.
+        """
+        QDesktopServices.openUrl(QUrl("https://github.com/Ultimaker/Cura/issues/new/choose"))
+
     def _onGlobalStackChanged(self) -> None:
         """Called when the global container stack changes"""
 
