@@ -7,12 +7,12 @@ from UM.Message import Message
 I18N_CATALOG = i18nCatalog("cura")
 
 
-## Message shown when uploading a print job to a cluster succeeded.
 class PrintJobUploadSuccessMessage(Message):
-    
+    """Message shown when uploading a print job to a cluster succeeded."""
+
     def __init__(self) -> None:
         super().__init__(
             text = I18N_CATALOG.i18nc("@info:status", "Print job was successfully sent to the printer."),
             title = I18N_CATALOG.i18nc("@info:title", "Data Sent"),
-            lifetime = 5
+            message_type = Message.MessageType.POSITIVE
         )
