@@ -1,10 +1,13 @@
-# Copyright (c) 2019 Ultimaker B.V.
+# Copyright (c) 2020 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
-from typing import List
+from typing import List, Optional
 
 from PyQt5.QtCore import pyqtProperty, pyqtSignal
 from PyQt5.QtGui import QImage
+from PyQt5.QtNetwork import QNetworkReply, QNetworkRequest
 
+from UM.Logger import Logger
+from UM.TaskManagement.HttpRequestManager import HttpRequestManager
 from cura.PrinterOutput.Models.PrintJobOutputModel import PrintJobOutputModel
 from cura.PrinterOutput.PrinterOutputController import PrinterOutputController
 
@@ -32,3 +35,13 @@ class UM3PrintJobOutputModel(PrintJobOutputModel):
         image = QImage()
         image.loadFromData(data)
         self.updatePreviewImage(image)
+
+    def loadPreviewImageFromUrl(self, url: str) -> None:
+        HttpRequestManager.getInstance().get(url=url, callback=self._onImageLoaded, error_callback=self._onImageLoaded)
+
+    def _onImageLoaded(self, reply: QNetworkReply, error: Optional["QNetworkReply.NetworkError"] = None) -> None:
+        if not HttpRequestManager.replyIndicatesSuccess(reply, error):
+            Logger.warning("Requesting preview image failed, response code {0} while trying to connect to {1}".format(
+                           reply.attribute(QNetworkRequest.HttpStatusCodeAttribute), reply.url()))
+            return
+        self.updatePreviewImageData(reply.readAll())
