@@ -49,7 +49,7 @@ class FirmwareUpdater(QObject):
         raise NotImplementedError("_updateFirmware needs to be implemented")
 
     def _cleanupAfterUpdate(self) -> None:
-        """Cleanup after a succesful update"""
+        """Cleanup after a successful update"""
 
         # Clean up for next attempt.
         self._update_firmware_thread = Thread(target=self._updateFirmware, daemon=True, name = "FirmwareUpdateThread")
